@@ -5,7 +5,7 @@ use lib qw(lib ../lib/ ../../hg_Gtk2-Ex-DbLinker-DbTools/lib/);
 use Gtk2 -init;
 use Log::Log4perl;
 Log::Log4perl->init("log.conf");
-
+#use Devel::Cycle;
 #use lib "../lib/";
 
 use Forms::Langues1;
@@ -25,7 +25,7 @@ my $dbh = DBI->connect(
 
 sub load_main_w {
 
-    Forms::Langues1->new( { gladefolder => "./Forms", dbh => $dbh } );
+   Forms::Langues1->new( { gladefolder => "./gladefiles", dbh => $dbh } );
 
 }
 
